@@ -3,7 +3,7 @@ from __future__ import annotations
 from jkUnicode import UniInfo
 from jkUnicode.tools.jsonhelpers import dict_from_file
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 
 class Orthography:
@@ -277,6 +277,37 @@ class Orthography:
             return True
         return False
 
+    def get_missing(
+        self, minimum: bool = False, punctuation: bool = False
+    ) -> Set[int]:
+        """
+        Return a set of missing characters for support of the orthography. If
+        `minimum` is true, only required characters are listed. If `punctuation`
+        is true, only punctuation characters are listed. If both are true, both
+        required and punctuation characters are listed. If both are false, all
+        required, optional, and punctuation characters are listed.
+
+        :param minimum: Only report missing required characters
+        :type minimum: bool
+        :param punctuation: Only report missing punctuation
+        :type punctuation: bool
+        """
+        missing = set()
+
+        if minimum:
+            missing = self.missing_base
+
+            if punctuation:
+                missing |= self.missing_punctuation
+
+        else:
+            if punctuation:
+                missing |= self.missing_punctuation
+            else:
+                missing |= self.missing_all
+
+        return missing
+
     def uses_unicode_base(self, u: int) -> bool:
         """
         Is the codepoint used by this orthography in the base set? This is
@@ -464,7 +495,10 @@ class OrthographyInfo:
         data_path = Path(__file__).resolve().parent / "json"
         master = dict_from_file(data_path, "language_characters")
         self.ignored_unicodes = set(
-            dict_from_file(data_path, "ignored_characters")
+            [
+                int(us, 16)
+                for us in dict_from_file(data_path, "ignored_characters")
+            ]
         )
         self.orthographies = []
         self._index = {}
@@ -707,8 +741,7 @@ class OrthographyInfo:
             unicodes_punctuation).
         :type attr: str
 
-        :param bcp47: Output orthographies as BCP47 language subtags instead of
-            human readable names
+        :param bcp47: Output BCP47 subtags instead of names
         :type bcp47: bool
         """
         otlist.sort()
@@ -726,6 +759,9 @@ class OrthographyInfo:
         """
         Print a report of minimally supported orthographies for the current
         cmap (no punctuation, no optional characters required).
+
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         m = self.get_supported_orthographies_minimum_inclusive()
         print(
@@ -743,6 +779,9 @@ class OrthographyInfo:
         """
         Print a report of minimally supported orthographies for the current
         cmap (no punctuation, no optional characters present).
+
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         m = self.get_supported_orthographies_minimum()
         print("The font has minimal support for %i orthographies:" % len(m))
@@ -760,6 +799,8 @@ class OrthographyInfo:
         :param full_only: Only report orthographies which have both basic and
             optional characters present
         :type full_only: bool
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         m = self.get_supported_orthographies(full_only)
         print("The font supports %i orthographies:" % len(m))
@@ -770,10 +811,50 @@ class OrthographyInfo:
             else:
                 print(ot.name)
 
+    def report_missing(
+        self, codes: List[str], minimum=False, punctuation=False, bcp47=False
+    ) -> None:
+        """
+        Print a report of missing characters for the given BCP47 language
+        subtags. If `minimum` is true, only required characters are listed. If
+        `punctuation` is true, only punctuation characters are listed. If both
+        are true, both required and punctuation characters are listed. If both
+        are false, all required, optional, and punctuation characters are
+        listed.
+
+        :param codes: BCP47 language subtags
+        :type codes: List[str]
+        :param minimum: Only report missing required characters
+        :type minimum: bool
+        :param punctuation: Only report missing punctuation
+        :type punctuation: bool
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
+        """
+        for code in codes:
+            o = self.orthography(*self.split_bcp47(code))
+            if o is None:
+                print(f"Orthography is unknown: {code}")
+                continue
+
+            missing = o.get_missing(minimum, punctuation)
+
+            if missing:
+                print(o.identifier if bcp47 else o.name)
+                for u in sorted(missing):
+                    self.ui.unicode = u
+                    print(
+                        "    0x%04X\t%s\t%s"
+                        % (u, self.ui.glyphname, self.ui.nice_name)
+                    )
+
     def report_missing_punctuation(self, bcp47=False) -> None:
         """
         Print a report of orthographies which have all basic letters present,
         but are missing puncuation characters.
+
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         m = self.get_almost_supported_punctuation()
         print(
@@ -785,6 +866,11 @@ class OrthographyInfo:
         """
         Print a report of orthographies which a maximum number of n characters
         missing.
+
+        :param n: The maximum number of missing characters
+        :type n: int
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         m = self.get_almost_supported(n)
         print(
@@ -797,6 +883,9 @@ class OrthographyInfo:
         """
         Print a list of character pairs that do not appear in any supported
         orthography for the current cmap.
+
+        :param bcp47: Output BCP47 subtags instead of names
+        :type bcp47: bool
         """
         import itertools
 
@@ -815,6 +904,22 @@ class OrthographyInfo:
         #     print("%s%s" % (chr(L), chr(R)))
         print(possible_pairs)
 
+    def split_bcp47(self, value: str) -> Tuple[str, str, str]:
+        code = value
+        script = "DFLT"
+        territory = "dflt"
+        if "-" in value:
+            parts = value.split("-")
+            assert len(parts) > 1
+            code = parts[0]
+            for part in parts[1:]:
+                if len(part) == 4:
+                    script = part
+                else:
+                    territory = part
+                    break
+        return code, script, territory
+
 
 # o = Orthography(
 #     info_obj=None,
