@@ -17,7 +17,7 @@ class RangeDict(dict):
             if k[0] <= key <= k[1]:
                 return v
         raise KeyError(
-            "Key '%s' is not between any values in the RangeDict" % key
+            f"Key '{key}' is not between any values in the RangeDict"
         )
 
     def __setitem__(self, key: Any, value: Any) -> None:
@@ -27,17 +27,16 @@ class RangeDict(dict):
                     dict.__setitem__(self, (key[0], key[1]), value)
                 else:
                     raise RuntimeError(
-                        "First element of a RangeDict key "
-                        "must be less than or equal to the "
-                        "second element"
+                        "First element of a RangeDict key must be less than or "
+                        "equal to the second element"
                     )
             else:
                 raise ValueError(
-                    "Key of a RangeDict must be an iterable " "with length two"
+                    "Key of a RangeDict must be an iterable with length two"
                 )
         except TypeError:
             raise TypeError(
-                "Key of a RangeDict must be an iterable " "with length two"
+                "Key of a RangeDict must be an iterable with length two"
             )
 
     def __contains__(self, key: Any) -> bool:
