@@ -509,6 +509,7 @@ uniScripts = {
     (0x1D183, 0x1D184): "Common",
     (0x1D18C, 0x1D1A9): "Common",
     (0x1D1AE, 0x1D1EA): "Common",
+    (0x1D2C0, 0x1D2D3): "Common",
     (0x1D2E0, 0x1D2F3): "Common",
     (0x1D300, 0x1D356): "Common",
     (0x1D360, 0x1D378): "Common",
@@ -578,10 +579,10 @@ uniScripts = {
     (0x1F300, 0x1F3FA): "Common",
     (0x1F3FB, 0x1F3FF): "Common",
     (0x1F400, 0x1F6D7): "Common",
-    (0x1F6DD, 0x1F6EC): "Common",
+    (0x1F6DC, 0x1F6EC): "Common",
     (0x1F6F0, 0x1F6FC): "Common",
-    (0x1F700, 0x1F773): "Common",
-    (0x1F780, 0x1F7D8): "Common",
+    (0x1F700, 0x1F776): "Common",
+    (0x1F77B, 0x1F7D9): "Common",
     (0x1F7E0, 0x1F7EB): "Common",
     (0x1F7F0, 0x1F7F0): "Common",
     (0x1F800, 0x1F80B): "Common",
@@ -592,15 +593,13 @@ uniScripts = {
     (0x1F8B0, 0x1F8B1): "Common",
     (0x1F900, 0x1FA53): "Common",
     (0x1FA60, 0x1FA6D): "Common",
-    (0x1FA70, 0x1FA74): "Common",
-    (0x1FA78, 0x1FA7C): "Common",
-    (0x1FA80, 0x1FA86): "Common",
-    (0x1FA90, 0x1FAAC): "Common",
-    (0x1FAB0, 0x1FABA): "Common",
-    (0x1FAC0, 0x1FAC5): "Common",
-    (0x1FAD0, 0x1FAD9): "Common",
-    (0x1FAE0, 0x1FAE7): "Common",
-    (0x1FAF0, 0x1FAF6): "Common",
+    (0x1FA70, 0x1FA7C): "Common",
+    (0x1FA80, 0x1FA88): "Common",
+    (0x1FA90, 0x1FABD): "Common",
+    (0x1FABF, 0x1FAC5): "Common",
+    (0x1FACE, 0x1FADB): "Common",
+    (0x1FAE0, 0x1FAE8): "Common",
+    (0x1FAF0, 0x1FAF8): "Common",
     (0x1FB00, 0x1FB92): "Common",
     (0x1FB94, 0x1FBCA): "Common",
     (0x1FBF0, 0x1FBF9): "Common",
@@ -669,6 +668,7 @@ uniScripts = {
     (0x1DF00, 0x1DF09): "Latin",
     (0x1DF0A, 0x1DF0A): "Latin",
     (0x1DF0B, 0x1DF1E): "Latin",
+    (0x1DF25, 0x1DF2A): "Latin",
     (0x0370, 0x0373): "Greek",
     (0x0375, 0x0375): "Greek",
     (0x0376, 0x0377): "Greek",
@@ -746,6 +746,8 @@ uniScripts = {
     (0xA69C, 0xA69D): "Cyrillic",
     (0xA69E, 0xA69F): "Cyrillic",
     (0xFE2E, 0xFE2F): "Cyrillic",
+    (0x1E030, 0x1E06D): "Cyrillic",
+    (0x1E08F, 0x1E08F): "Cyrillic",
     (0x0531, 0x0556): "Armenian",
     (0x0559, 0x0559): "Armenian",
     (0x055A, 0x055F): "Armenian",
@@ -830,6 +832,7 @@ uniScripts = {
     (0xFE70, 0xFE74): "Arabic",
     (0xFE76, 0xFEFC): "Arabic",
     (0x10E60, 0x10E7E): "Arabic",
+    (0x10EFD, 0x10EFF): "Arabic",
     (0x1EE00, 0x1EE03): "Arabic",
     (0x1EE05, 0x1EE1F): "Arabic",
     (0x1EE21, 0x1EE22): "Arabic",
@@ -902,6 +905,7 @@ uniScripts = {
     (0xA8FC, 0xA8FC): "Devanagari",
     (0xA8FD, 0xA8FE): "Devanagari",
     (0xA8FF, 0xA8FF): "Devanagari",
+    (0x11B00, 0x11B09): "Devanagari",
     (0x0980, 0x0980): "Bengali",
     (0x0981, 0x0981): "Bengali",
     (0x0982, 0x0983): "Bengali",
@@ -1079,6 +1083,7 @@ uniScripts = {
     (0x0CE2, 0x0CE3): "Kannada",
     (0x0CE6, 0x0CEF): "Kannada",
     (0x0CF1, 0x0CF2): "Kannada",
+    (0x0CF3, 0x0CF3): "Kannada",
     (0x0D00, 0x0D01): "Malayalam",
     (0x0D02, 0x0D03): "Malayalam",
     (0x0D04, 0x0D0C): "Malayalam",
@@ -1140,7 +1145,7 @@ uniScripts = {
     (0x0EBD, 0x0EBD): "Lao",
     (0x0EC0, 0x0EC4): "Lao",
     (0x0EC6, 0x0EC6): "Lao",
-    (0x0EC8, 0x0ECD): "Lao",
+    (0x0EC8, 0x0ECE): "Lao",
     (0x0ED0, 0x0ED9): "Lao",
     (0x0EDC, 0x0EDF): "Lao",
     (0x0F00, 0x0F00): "Tibetan",
@@ -1349,6 +1354,7 @@ uniScripts = {
     (0x309D, 0x309E): "Hiragana",
     (0x309F, 0x309F): "Hiragana",
     (0x1B001, 0x1B11F): "Hiragana",
+    (0x1B132, 0x1B132): "Hiragana",
     (0x1B150, 0x1B152): "Hiragana",
     (0x1F200, 0x1F200): "Hiragana",
     (0x30A1, 0x30FA): "Katakana",
@@ -1364,6 +1370,7 @@ uniScripts = {
     (0x1AFFD, 0x1AFFE): "Katakana",
     (0x1B000, 0x1B000): "Katakana",
     (0x1B120, 0x1B122): "Katakana",
+    (0x1B155, 0x1B155): "Katakana",
     (0x1B164, 0x1B167): "Katakana",
     (0x02EA, 0x02EB): "Bopomofo",
     (0x3105, 0x312F): "Bopomofo",
@@ -1384,12 +1391,13 @@ uniScripts = {
     (0x16FE3, 0x16FE3): "Han",
     (0x16FF0, 0x16FF1): "Han",
     (0x20000, 0x2A6DF): "Han",
-    (0x2A700, 0x2B738): "Han",
+    (0x2A700, 0x2B739): "Han",
     (0x2B740, 0x2B81D): "Han",
     (0x2B820, 0x2CEA1): "Han",
     (0x2CEB0, 0x2EBE0): "Han",
     (0x2F800, 0x2FA1D): "Han",
     (0x30000, 0x3134A): "Han",
+    (0x31350, 0x323AF): "Han",
     (0xA000, 0xA014): "Yi",
     (0xA015, 0xA015): "Yi",
     (0xA016, 0xA48C): "Yi",
@@ -1670,8 +1678,11 @@ uniScripts = {
     (0xAADE, 0xAADF): "Tai_Viet",
     (0x10B00, 0x10B35): "Avestan",
     (0x10B39, 0x10B3F): "Avestan",
-    (0x13000, 0x1342E): "Egyptian_Hieroglyphs",
-    (0x13430, 0x13438): "Egyptian_Hieroglyphs",
+    (0x13000, 0x1342F): "Egyptian_Hieroglyphs",
+    (0x13430, 0x1343F): "Egyptian_Hieroglyphs",
+    (0x13440, 0x13440): "Egyptian_Hieroglyphs",
+    (0x13441, 0x13446): "Egyptian_Hieroglyphs",
+    (0x13447, 0x13455): "Egyptian_Hieroglyphs",
     (0x0800, 0x0815): "Samaritan",
     (0x0816, 0x0819): "Samaritan",
     (0x081A, 0x081A): "Samaritan",
@@ -1877,6 +1888,8 @@ uniScripts = {
     (0x11236, 0x11237): "Khojki",
     (0x11238, 0x1123D): "Khojki",
     (0x1123E, 0x1123E): "Khojki",
+    (0x1123F, 0x11240): "Khojki",
+    (0x11241, 0x11241): "Khojki",
     (0x10600, 0x10736): "Linear_A",
     (0x10740, 0x10755): "Linear_A",
     (0x10760, 0x10767): "Linear_A",
@@ -2162,4 +2175,21 @@ uniScripts = {
     (0x105A3, 0x105B1): "Vithkuqi",
     (0x105B3, 0x105B9): "Vithkuqi",
     (0x105BB, 0x105BC): "Vithkuqi",
+    (0x11F00, 0x11F01): "Kawi",
+    (0x11F02, 0x11F02): "Kawi",
+    (0x11F03, 0x11F03): "Kawi",
+    (0x11F04, 0x11F10): "Kawi",
+    (0x11F12, 0x11F33): "Kawi",
+    (0x11F34, 0x11F35): "Kawi",
+    (0x11F36, 0x11F3A): "Kawi",
+    (0x11F3E, 0x11F3F): "Kawi",
+    (0x11F40, 0x11F40): "Kawi",
+    (0x11F41, 0x11F41): "Kawi",
+    (0x11F42, 0x11F42): "Kawi",
+    (0x11F43, 0x11F4F): "Kawi",
+    (0x11F50, 0x11F59): "Kawi",
+    (0x1E4D0, 0x1E4EA): "Nag_Mundari",
+    (0x1E4EB, 0x1E4EB): "Nag_Mundari",
+    (0x1E4EC, 0x1E4EF): "Nag_Mundari",
+    (0x1E4F0, 0x1E4F9): "Nag_Mundari",
 }
